=== modified file 'hooks/horizon-relations'
--- hooks/horizon-relations	2013-02-14 15:19:04 +0000
+++ hooks/horizon-relations	2013-02-26 17:26:20 +0000
@@ -79,6 +79,14 @@
   set_or_update LOGIN_URL "$web_root/auth/login"
   set_or_update LOGIN_REDIRECT_URL "$web_root"
 
+  # Save our scriptrc env variables for health checks
+  declare -a env_vars=(
+      'OPENSTACK_URL_HORIZON_CHECK=http://localhost/$web_root|Login - Openstack'
+      'OPENSTACK_SERVICE_HORIZON=apache2'
+      'OPENSTACK_PORT_HORIZON=80')
+  save_script_rc ${env_vars[@]}
+
+
   # Set default role and trigger a identity-service relation event to
   # ensure role is created in keystone.
   set_or_update OPENSTACK_KEYSTONE_DEFAULT_ROLE "$(config-get default-role)"

=== modified file 'hooks/lib/openstack-common'
--- hooks/lib/openstack-common	2013-02-15 15:52:40 +0000
+++ hooks/lib/openstack-common	2013-02-26 17:26:20 +0000
@@ -315,6 +315,43 @@
   return 0
 }
 
+##########################################################################
+# Description: Creates an rc file exporting environment variables to a
+# script_path local to the charm's installed directory.
+# Any charm scripts run outside the juju hook environment can source this
+# scriptrc to obtain updated config information necessary to perform health
+# checks or service changes
+#
+# Parameters: 
+#   An array of '=' delimited  ENV_VAR:value combinations to export.
+#   If optional script_path key is not provided in the array, script_path
+#     defaults to scripts/scriptrc
+##########################################################################
+function save_script_rc {
+  if [ ! -n "$JUJU_UNIT_NAME" ]; then
+     echo "Error: Missing JUJU_UNIT_NAME environment variable"
+     exit 1
+  fi
+  # our default unit_path
+  unit_path="/var/lib/juju/units/${JUJU_UNIT_NAME/\//-}/charm/scripts/scriptrc"
+  echo $unit_path
+  tmp_rc="/tmp/${JUJU_UNIT_NAME/\//-}rc"
+
+  echo "#!/bin/bash" > $tmp_rc
+  for env_var in "${@}"
+  do
+    if `echo $env_var | grep -q script_path`; then
+       # well then we need to reset the new unit-local script path
+       unit_path="/var/lib/juju/units/${JUJU_UNIT_NAME/\//-}/charm/${env_var/script_path=/}"
+    else
+       echo "export $env_var" >> $tmp_rc
+    fi 
+  done
+  chmod 755 $tmp_rc
+  mv $tmp_rc $unit_path
+}
+
+
 HAPROXY_CFG=/etc/haproxy/haproxy.cfg
 HAPROXY_DEFAULT=/etc/default/haproxy
 

=== modified file 'revision'
--- revision	2013-01-11 21:59:22 +0000
+++ revision	2013-02-26 17:26:20 +0000
@@ -1,1 +1,1 @@
-22
+23

=== added directory 'scripts'
=== added file 'scripts/add_to_cluster'
--- scripts/add_to_cluster	1970-01-01 00:00:00 +0000
+++ scripts/add_to_cluster	2013-02-26 17:26:20 +0000
@@ -0,0 +1,2 @@
+#!/bin/bash
+crm node online

=== added directory 'scripts/health_checks.d'
=== added file 'scripts/health_checks.d/service_ports_live'
--- scripts/health_checks.d/service_ports_live	1970-01-01 00:00:00 +0000
+++ scripts/health_checks.d/service_ports_live	2013-02-26 17:26:20 +0000
@@ -0,0 +1,13 @@
+#!/bin/bash
+# Validate that service ports are active
+HEALTH_DIR=`dirname $0`
+SCRIPTS_DIR=`dirname $HEALTH_DIR`
+. $SCRIPTS_DIR/scriptrc
+set -e
+
+# Grab any OPENSTACK_PORT* environment variables
+openstack_ports=`env| awk -F '=' '(/OPENSTACK_PORT/){print $2}'`
+for port in $openstack_ports
+do
+    netstat -ln | grep -q $port
+done

=== added file 'scripts/health_checks.d/service_running'
--- scripts/health_checks.d/service_running	1970-01-01 00:00:00 +0000
+++ scripts/health_checks.d/service_running	2013-02-26 17:26:20 +0000
@@ -0,0 +1,13 @@
+#!/bin/bash
+# Validate that service is running
+HEALTH_DIR=`dirname $0`
+SCRIPTS_DIR=`dirname $HEALTH_DIR`
+. $SCRIPTS_DIR/scriptrc
+set -e
+
+# Grab any OPENSTACK_SERVICE* environment variables
+openstack_service_names=`env| awk -F '=' '(/OPENSTACK_SERVICE/){print $2}'`
+for service_name in $openstack_service_names
+do
+    service $service_name status 2>/dev/null | grep -q running
+done

=== added file 'scripts/health_checks.d/service_url_checks'
--- scripts/health_checks.d/service_url_checks	1970-01-01 00:00:00 +0000
+++ scripts/health_checks.d/service_url_checks	2013-02-26 17:26:20 +0000
@@ -0,0 +1,16 @@
+#!/bin/bash
+# Validate that service urls return expected content
+HEALTH_DIR=`dirname $0`
+SCRIPTS_DIR=`dirname $HEALTH_DIR`
+. $SCRIPTS_DIR/scriptrc
+set -e
+
+# Grab any OPENSTACK_URL* environment variables and validate content response
+openstack_urls=`env| awk -F '=' '(/OPENSTACK_URL/){print $2}'`
+for url_check in $openstack_urls
+do
+    url=`echo $url_check| awk -F '|' '{print $1}'`
+    expected_content=`echo $url_check| awk -F '|' '{print $2}'`
+    wget -q -O - $url | grep -q "$expected_content"
+done
+

=== added file 'scripts/remove_from_cluster'
--- scripts/remove_from_cluster	1970-01-01 00:00:00 +0000
+++ scripts/remove_from_cluster	2013-02-26 17:26:20 +0000
@@ -0,0 +1,2 @@
+#!/bin/bash
+crm node standby

